@@ -1,7 +1,7 @@
 from datetime import datetime
 import json
 import logging
-from typing import List, Optional
+from typing import List, Optional, Union
 import uuid
 
 from werkzeug.security import generate_password_hash
@@ -408,8 +408,10 @@ class SecurityManager(BaseSecurityManager):
             except Exception as e:
                 log.error(c.LOGMSG_ERR_SEC_DEL_PERMROLE.format(str(e)))
 
-    def export_roles(self, path: Optional[str] = None) -> None:
-        """ Exports roles to JSON file. """
+    def export_roles(
+        self, path: Optional[str] = None, indent: Optional[Union[int, str]] = None
+    ) -> None:
+        """Exports roles to JSON file."""
         timestamp = datetime.now().strftime("%Y%m%dT%H%M%S")
         filename = path or f"roles_export_{timestamp}.json"
 
@@ -430,7 +432,7 @@ class SecurityManager(BaseSecurityManager):
             serialized_roles.append(serialized_role)
 
         with open(filename, "w") as fd:
-            fd.write(json.dumps(serialized_roles))
+            fd.write(json.dumps(serialized_roles, indent=indent))
 
     def import_roles(self, path: str) -> None:
         """ Imports roles from JSON file. """
@@ -450,3 +452,9 @@ class SecurityManager(BaseSecurityManager):
             role.permissions = permission_view_menus
 
             role.save()
+
+    def get_first_user(self) -> "User":
+        return self.user_model.objects.first()
+
+    def noop_user_update(self, user: "User") -> None:
+        pass
